pub enum PortOutputSubcommand {
Show 15 variants
StartPower2 {
power1: Power,
power2: Power,
},
SetAccTime {
time: i16,
profile_number: i8,
},
SetDecTime {
time: i16,
profile_number: i8,
},
StartSpeed {
speed: i8,
max_power: u8,
use_acc_profile: bool,
use_dec_profile: bool,
},
StartSpeedNoPower {
speed: i8,
max_power: u8,
use_acc_profile: bool,
use_dec_profile: bool,
},
StartSpeed2 {
speed1: i8,
speed2: i8,
max_power: u8,
use_acc_profile: bool,
use_dec_profile: bool,
},
StartSpeedForTime {
time: i16,
speed: i8,
max_power: u8,
end_state: EndState,
use_acc_profile: bool,
use_dec_profile: bool,
},
StartSpeedForTime2 {
time: i16,
speed_l: i8,
speed_r: i8,
max_power: u8,
end_state: EndState,
use_acc_profile: bool,
use_dec_profile: bool,
},
StartSpeedForDegrees {
degrees: i32,
speed: i8,
max_power: u8,
end_state: EndState,
use_acc_profile: bool,
use_dec_profile: bool,
},
StartSpeedForDegrees2 {
degrees: i32,
speed_l: i8,
speed_r: i8,
max_power: u8,
end_state: EndState,
use_acc_profile: bool,
use_dec_profile: bool,
},
GotoAbsolutePosition {
abs_pos: i32,
speed: i8,
max_power: u8,
end_state: EndState,
use_acc_profile: bool,
use_dec_profile: bool,
},
GotoAbsolutePosition2 {
abs_pos1: i32,
abs_pos2: i32,
speed: i8,
max_power: u8,
end_state: EndState,
use_acc_profile: bool,
use_dec_profile: bool,
},
PresetEncoder2 {
left_position: i32,
right_position: i32,
},
WriteDirect(WriteDirectPayload),
WriteDirectModeData(WriteDirectModeDataPayload),
}Variants
StartPower2
This has a subcommand number and also a “writedirectmodedata” annotation so I have no idea where this really lives
According to () it does live here () https://github.com/LEGO/lego-ble-wireless-protocol-docs/issues/15
SetAccTime
SetDecTime
StartSpeed
StartSpeedNoPower
StartSpeed2
StartSpeedForTime
Fields
StartSpeedForTime2
Fields
StartSpeedForDegrees
Fields
StartSpeedForDegrees2
Fields
GotoAbsolutePosition
Fields
GotoAbsolutePosition2
Fields
PresetEncoder2
WriteDirect(WriteDirectPayload)
WriteDirectModeData(WriteDirectModeDataPayload)
Implementations