PortValueCombinedFormat

Struct PortValueCombinedFormat 

pub struct PortValueCombinedFormat {
    pub port_id: u8,
    pub data: Vec<u8>,
}
The PortValueCombinedFormat is some horrific set of pointers to values we should already have cached elsewhere. For now we save the raw data and leave parsing it for later.

Fields

port_id: u8data: Vec<u8>

Implementations

Source

impl PortValueCombinedFormat

pub fn parse<'a>(msg: impl Iterator<Item = &'a u8>) -> Result<Self>