pub struct PortValueCombinedFormat {
pub port_id: u8,
pub data: Vec<u8>,
}Expand description
The PortValueCombinedFormat is some horrific set of pointers to values we should already have cached elsewhere. For now we save the raw data and leave parsing it for later.
Fields
port_id: u8data: Vec<u8>Implementations